==> ocg_login-0.0.1.tar.gz: lib/src/screens/splash_screen.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../blocs/login/bloc.dart';
import '../blocs/login/event.dart';
import '../blocs/login/state.dart';
import '../routes/routes.dart';

class LoginSplashScreen extends StatefulWidget {
  @override
  _LoginSplashScreenState createState() => _LoginSplashScreenState();
}

class _LoginSplashScreenState extends State<LoginSplashScreen>
    with TickerProviderStateMixin<LoginSplashScreen> {
  AnimationController controller;
  AnimationController textController;
  CurvedAnimation animation;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        vsync: this, duration: Duration(milliseconds: 1000));
    textController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 750));
    animation = CurvedAnimation(parent: controller, curve: Curves.easeOut);
    // Brightness
    SystemChrome.setPreferredOrientations(
        [DeviceOrientation.portraitDown, DeviceOrientation.portraitUp]);
    runAmimations();
    WidgetsBinding.instance.addPostFrameCallback((timeStamp) {
      BlocProvider.of<LoginBloc>(context).add(LoginCheckEvent());
    });
  }

  Future<void> runAmimations() async {
    await controller.forward();
    await textController.forward();
    await Future.delayed(Duration(milliseconds: 200));
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.light
          .copyWith(statusBarColor: Colors.transparent),
      child: Scaffold(
        body: BlocListener<LoginBloc, LoginState>(
          listener: (context, state) {
            debugPrint("State $state");
            if (state is LoginNotCompleteState) {
              debugPrint("Start");
              Navigator.of(context).pushNamed(LoginRouteType.profileRoute);
            } else if (state is LoginExistState) {
              AppActionHandler.of(context).goHome();
            }
          },
          child: Container(
            // TODO Replace with your background color
            decoration: BoxDecoration(color: Colors.red),
            child: Center(
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  AnimatedBuilder(
                    animation: controller,
                    builder: (context, child) {
                      return Transform.scale(
                        scale: animation.value,
                        child: child,
                      );
                    },
                    child: Hero(
                      tag: "Splash",
                      child: SizedBox(
                          width: MediaQuery.of(context).size.width / 2,
                          height: MediaQuery.of(context).size.width / 2,
                          // TODO Add company logo
                          child: FlutterLogo()),
                    ),
                  ),
                  SizedBox(
                    height: 12,
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 16),
                    child: AnimatedBuilder(
                      animation: textController,
                      builder: (context, child) {
                        return FadeTransition(
                          opacity: textController,
                          child: child,
                        );
                      },
                      child: Text(
                        // TODO Logo
                        "Flutter",
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: 20,
                            fontWeight: FontWeight.w600),
                        textAlign: TextAlign.center,
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    textController.dispose();
    super.dispose();
  }
}

==> ocg_login-0.0.4.tar.gz: lib/src/screens/splash_screen.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../blocs/login/bloc.dart';
import '../blocs/login/event.dart';
import '../blocs/login/state.dart';
import '../routes/routes.dart';

class LoginSplashScreen extends StatefulWidget {
  @override
  _LoginSplashScreenState createState() => _LoginSplashScreenState();
}

class _LoginSplashScreenState extends State<LoginSplashScreen>
    with TickerProviderStateMixin<LoginSplashScreen> {
  AnimationController controller;
  AnimationController textController;
  CurvedAnimation animation;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        vsync: this, duration: Duration(milliseconds: 1000));
    textController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 750));
    animation = CurvedAnimation(parent: controller, curve: Curves.easeOut);
    // Brightness
    SystemChrome.setPreferredOrientations(
        [DeviceOrientation.portraitDown, DeviceOrientation.portraitUp]);
    runAmimations();
  }

  Future<void> runAmimations() async {
    await controller.forward();
    await textController.forward();
    BlocProvider.of<LoginBloc>(context).add(LoginCheckEvent());
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.light
          .copyWith(statusBarColor: Colors.transparent),
      child: Scaffold(
        body: BlocListener<LoginBloc, LoginState>(
          listener: (context, state) {
            if (state is LoginNotExistState) {
              Navigator.of(context).pushNamed(LoginRouteType.loginRoute);
            } else if (state is LoginExistState) {
              AppActionHandler.of(context).goHome();
            }
          },
          child: Container(
            child: Center(
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  AnimatedBuilder(
                    animation: controller,
                    builder: (context, child) {
                      return Transform.scale(
                        scale: animation.value,
                        child: child,
                      );
                    },
                    child: Hero(
                      tag: "Splash",
                      child: SizedBox(
                          width: MediaQuery.of(context).size.width / 2,
                          height: MediaQuery.of(context).size.width / 2,
                          // TODO Add company logo
                          child: FlutterLogo()),
                    ),
                  ),
                  SizedBox(
                    height: 12,
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 16),
                    child: AnimatedBuilder(
                      animation: textController,
                      builder: (context, child) {
                        return FadeTransition(
                          opacity: textController,
                          child: child,
                        );
                      },
                      child: Text(
                        // TODO Logo
                        "Flutter",
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: 20,
                            fontWeight: FontWeight.w600),
                        textAlign: TextAlign.center,
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    textController.dispose();
    super.dispose();
  }
}
